# frozen_string_literal: true

module FlakeySpecCatcher
  # ChangeSummary class
  #
  # Takes in a git diff block summary and converts it to an object.
  #
  # This class converts a block of changes (retrieved through use of git diff)
  # into an object that will allow the created ChangeCapsule objects to more
  # easily find and identify changes.
  class ChangeSummary
    attr_reader :master_commit_line_number, :master_commit_lines_altered
    attr_reader :working_commit_line_number, :working_commit_lines_altered
    attr_reader :change_type

    def initialize(change_summary)
      @master_commit_line_number, @master_commit_lines_altered =
        change_summary.split[0].delete('-').split(',').map(&:to_i)
      @master_commit_lines_altered ||= 0
      @working_commit_line_number, @working_commit_lines_altered =
        change_summary.split[1].delete('+').split(',').map(&:to_i)
      @working_commit_lines_altered ||= 0
      initialize_change_type
    end

    private

    def initialize_change_type
      @change_type = if @working_commit_lines_altered >= @master_commit_lines_altered
        'ADD'
      else
        'REMOVE'
      end
    end
  end
end
