# frozen_string_literal: true

require 'rspec'

module FlakeySpecCatcher
  # EventListener class
  #
  # Listens for events from RSpec and processes data from those events.
  #
  # This event listener will receive example_failed and example_passed events
  # from RSpec and will log those results into the provided result manager
  class EventListener
    def initialize(result_manager)
      @result_manager = result_manager
    end

    def example_failed(notification)
      description = notification.example.full_description.to_s.strip
      location = notification.example.location
      @result_manager.add_result(description, location, format_message(notification))
    end

    def example_passed(notification)
      description = notification.example.full_description.to_s.strip
      location = notification.example.location
      @result_manager.add_result(description, location)
    end

    private

    def format_message(notification)
      exception = notification.example.execution_result.exception
      message = if exception.is_a?(RSpec::Core::MultipleExceptionError)
        exception.all_exceptions.join("\n").strip
      else
        exception.to_s.strip
      end

      message
    end
  end
end
