# frozen_string_literal: true

module FlakeySpecCatcher
  # RerunCapsule class
  #
  # Contains one file or test case to re-run, as well as its associated RSpec
  # usage.
  class RerunCapsule
    include Comparable
    attr_reader :usage, :testcase

    def initialize(usage: nil, testcase: [])
      @usage = initialize_usage(usage)
      @testcase = initialize_testcase(testcase)
    end

    def empty?
      if testcase.empty?
        true
      else
        false
      end
    end

    def default_usage?
      @usage.nil?
    end

    def <=>(other)
      @testcase <=> other.testcase
    end

    def ==(other)
      usage == other.usage && testcase == other.testcase
    end

    private

    def initialize_usage(usage)
      if usage.nil? || usage.empty?
        nil
      else
        usage
      end
    end

    def initialize_testcase(testcase)
      if testcase.nil? || testcase.empty?
        []
      elsif testcase.is_a?(Array)
        testcase
      else
        raise "Error: expected array for testcase not #{testcase.class}"
      end
    end
  end
end
